summaryrefslogtreecommitdiff
path: root/wram.asm
diff options
context:
space:
mode:
Diffstat (limited to 'wram.asm')
-rwxr-xr-xwram.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/wram.asm b/wram.asm
index c6eb750e..b2332f61 100755
--- a/wram.asm
+++ b/wram.asm
@@ -897,7 +897,7 @@ wBadgeNameTile::
; first tile ID of the name being drawn
wFlyLocationsList::
; 11 bytes plus $ff sentinel values at each end
wSlotMachineWheel1Offset::
@@ -2818,7 +2818,7 @@ wWalkBikeSurfState::
ds 10
wTownVisitedFlag::
- flag_array 13
+ flag_array NUM_CITY_MAPS
wSafariSteps::
; starts at 502
@@ -897,7 +897,7 @@ wBadgeNameTile::
; first tile ID of the name being drawn
wFlyLocationsList::
-; 11 bytes plus $ff sentinel values at each end
+; NUM_CITY_MAPS bytes plus $ff sentinel values at each end
wSlotMachineWheel1Offset::